#include <vector>
#include "../math/complex.hh"

using namespace std;


// NLO

struct s_complex { double re; double im; };
extern "C" {
  s_complex harlander_(s_complex *x, s_complex *t);
}

dcomplex born_q_ep0(dcomplex x) {
  dcomplex logx = log(x+I*1e-60);
  dcomplex HPL2 = 0.5*logx*logx;
  return -16.*(1.+x)*(1.+x)/x*HPL2 + 32.*(x-1.)*(x-1.)/x;
}

double higgs_nlo_G2l(double mh, double mt, double mb, double mc) {
  int number_of_quarks = 1;
  vector<double> m;
  m.push_back(mt);
  if(mb>0) { number_of_quarks++; m.push_back(mb); }
  if(mc>0) { number_of_quarks++; m.push_back(mc); }
  dcomplex F0H=0, num=0;
  for(int i=0; i<number_of_quarks; i++) {
    dcomplex Wq = 4.*m[i]*m[i]/mh/mh;
    dcomplex Xq = -Wq/pow(1.+sqrt(1.-Wq),2);
    F0H += born_q_ep0(Xq)*Wq*Wq /64.*(-3./4.);
    dcomplex t = pow(mh/2./m[i],2) + I*1.e-15;
    dcomplex x = (sqrt(1-1./t)-1)/(sqrt(1-1./t)+1);
    s_complex res, xx={real(x),imag(x)}, tt={real(t),imag(t)};
    res = harlander_(&xx, &tt);
    num += dcomplex(res.re,res.im);
  }
  return real(num/F0H);
}



// NNLO

int higgs_nnlo_delta_term(double mH, double mt, int nl) {
  double xht = mH*mH/mt/mt;
  double lmtop = 2.*log(mH/mt);
  double res[4];
  res[0] =  2.3750000000000000e+00*lmtop-9.9967871365584937e+00*nl+6.6666666666666663e-01*lmtop*nl+1.3774537677437098e+02;
  res[1] =  8.1759259259259254e-01*lmtop+1.7171088945089927e-01*nl-9.7569444444444445e-02*lmtop*nl+6.8056800245389057e+00;
  res[2] =  7.7912808641975306e-02*lmtop-2.6699459428352916e-03*nl-8.9068470752498522e-03*lmtop*nl+9.9039412522480075e-01;
  res[3] =  1.1558035583060384e-02*lmtop-1.4857221513806470e-03*nl-1.2217801350221159e-03*lmtop*nl+1.6055632752619473e-01;
  return res[0] + res[1]*xht + res[2]*xht*xht + res[3]*xht*xht*xht;
}


