#pragma once
#include <cmath>
#include "PDFinterface.hh"
//#include "math/complex.hh"



enum process {
  DISneutralPlus = -100,  // positron projectile
  DISneutralMinus= -101,  // electron projectile
  DISneutral     = -1,    // average
  DISchargedWpnu = -2,
  DISchargedWmnu = -3,
  DISchargedWpe  = -4,
  DISchargedWme  = -5,
  DISneutralCharm      = -10,
  DISneutralCharmPlus  = -11,
  DISneutralCharmMinus = -12,
  DISchargedCharmWpnu = -6,
  DISchargedCharmWmnu = -7,
  DISchargedCharmWpe  = -8,
  DISchargedCharmWme  = -9,
  ggH        =  0,
  DYneutral  =  1,
  DYpositive =  2,
  DYnegative =  3
};
enum collider {
  // for hadron-hadron colliders
  pp       =  0,
  ppbar    =  1,
  LHC      =  0,
  Tevatron =  1,
  pd       =  2,
  // for DIS
  proton   = -1,
  deuteron = -2,
  iron     = -3
};

enum DISobservable {
  F2 = 0,
  F3 = 1,
  sigma = 2
};

namespace lumi {

  extern double lumi_gg (PDFinterface::PDFs *pdfs, double x1, double x2, double mu);
  extern double lumi_DY (PDFinterface::PDFs *pdfs, double x1, double x2, double mu, double M, process p, collider c);
  extern double lumi_DIS(PDFinterface::PDFs *pdfs, double x, double mu, int nf, process p, collider c, double y, double TMoQ=0, double mcoQ=0); // nf is the number of active flavours

  extern void SetZcoupling(double); // 1: SM, 0: excludes the Z
  extern void SetDISObservable(DISobservable obs);

  extern double NFV(double mu, process p);

};


